@@ -8,11 +8,11 @@ data_name = "lens_light__source_smooth"
 instrument = "vro"
 
 
-def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
+def make_pipeline(name, folders, search=af.DynestyStatic()):
 
     phase1 = al.PhaseImaging(
         phase_name="phase_1",
-        folders=setup.folders,
+        folders=folders,
         galaxies=dict(
             lens=al.GalaxyModel(
                 redshift=0.5,
@@ -26,12 +26,12 @@ def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
 
     phase1.search.const_efficiency_mode = True
     phase1.search.n_live_points = 40
-    phase1.search.sampling_efficiency = 0.8
+    phase1.search.facc = 0.8
     phase1.search.evidence_tolerance = 10.0
 
     phase2 = al.PhaseImaging(
         phase_name="phase_2",
-        folders=setup.folders,
+        folders=folders,
         galaxies=dict(
             lens=phase1.result.instance.galaxies.lens,
             source=al.GalaxyModel(
@@ -46,16 +46,16 @@ def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
 
     phase2.search.const_efficiency_mode = True
     phase2.search.n_live_points = 40
-    phase2.search.sampling_efficiency = 0.8
+    phase2.search.facc = 0.8
     phase2.search.evidence_tolerance = 1000.0
 
     phase2 = phase2.extend_with_multiple_hyper_phases(
-        hyper_galaxies_search=True, inversion_search=True
+        hyper_galaxies_search=True, include_inversion=True
     )
 
     phase3 = al.PhaseImaging(
         phase_name="phase_3",
-        folders=setup.folders,
+        folders=folders,
         galaxies=dict(
             lens=phase1.result.model.galaxies.lens,
             source=phase2.result.instance.galaxies.source,
@@ -66,11 +66,11 @@ def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
 
     phase3.search.const_efficiency_mode = True
     phase3.search.n_live_points = 40
-    phase3.search.sampling_efficiency = 0.8
+    phase3.search.facc = 0.8
     phase3.search.evidence_tolerance = 1000.0
 
     phase3 = phase3.extend_with_multiple_hyper_phases(
-        hyper_galaxies_search=True, inversion_search=True
+        hyper_galaxies_search=True, include_inversion=True
     )
 
     return al.PipelineDataset(name, phase1, phase2, phase3)
