@@ -8,11 +8,11 @@ data_name = "lens_sie__source_smooth"
 instrument = "hst"
 
 
-def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
+def make_pipeline(name, folders, search=af.DynestyStatic()):
 
     phase1 = al.PhaseImaging(
         phase_name="phase_1",
-        folders=setup.folders,
+        folders=folders,
         galaxies=dict(
             lens=al.GalaxyModel(redshift=0.5, mass=al.mp.EllipticalIsothermal),
             source=al.GalaxyModel(redshift=1.0, light=al.lp.EllipticalSersic),
@@ -22,7 +22,7 @@ def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
 
     phase1.search.const_efficiency_mode = True
     phase1.search.n_live_points = 40
-    phase1.search.sampling_efficiency = 0.8
+    phase1.search.facc = 0.8
     phase1.search.evidence_tolerance = 10.0
 
     phase1 = phase1.extend_with_multiple_hyper_phases(
@@ -33,7 +33,7 @@ def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
 
     phase2 = al.PhaseImaging(
         phase_name="phase_2",
-        folders=setup.folders,
+        folders=folders,
         galaxies=dict(
             lens=al.GalaxyModel(
                 redshift=0.5, mass=phase1.result.instance.galaxies.lens.mass
@@ -49,12 +49,12 @@ def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
 
     phase2.search.const_efficiency_mode = True
     phase2.search.n_live_points = 40
-    phase2.search.sampling_efficiency = 0.8
+    phase2.search.facc = 0.8
     phase2.search.evidence_tolerance = 10.0
 
     phase3 = al.PhaseImaging(
         phase_name="phase_3",
-        folders=setup.folders,
+        folders=folders,
         galaxies=dict(
             lens=al.GalaxyModel(redshift=0.5, mass=phase1.model.galaxies.lens.mass),
             source=al.GalaxyModel(
@@ -68,12 +68,12 @@ def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
 
     phase3.search.const_efficiency_mode = True
     phase3.search.n_live_points = 40
-    phase3.search.sampling_efficiency = 0.8
+    phase3.search.facc = 0.8
     phase3.search.evidence_tolerance = 10.0
 
     phase4 = al.PhaseImaging(
         phase_name="phase_4_weighted_regularization",
-        folders=setup.folders,
+        folders=folders,
         galaxies=dict(
             lens=al.GalaxyModel(
                 redshift=0.5, mass=phase3.result.instance.galaxies.lens.mass
@@ -89,7 +89,7 @@ def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
 
     phase4.search.const_efficiency_mode = True
     phase4.search.n_live_points = 40
-    phase4.search.sampling_efficiency = 0.8
+    phase4.search.facc = 0.8
     phase4.search.evidence_tolerance = 10.0
 
     return al.PipelineDataset(name, phase1, phase2, phase3, phase4)
