@@ -8,7 +8,7 @@ data_name = "lens_sis__source_smooth__offset_centre"
 instrument = "vro"
 
 
-def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
+def make_pipeline(name, folders, search=af.DynestyStatic()):
     class LensPhase(al.PhaseImaging):
         def customize_priors(self, results):
 
@@ -19,7 +19,7 @@ def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
 
     phase1 = LensPhase(
         phase_name="phase_1",
-        folders=setup.folders,
+        folders=folders,
         galaxies=dict(
             lens=al.GalaxyModel(redshift=0.5, mass=al.mp.SphericalIsothermal),
             source=al.GalaxyModel(redshift=1.0, light=al.lp.EllipticalSersic),
@@ -30,7 +30,7 @@ def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
 
     phase1.search.const_efficiency_mode = True
     phase1.search.n_live_points = 30
-    phase1.search.sampling_efficiency = 0.8
+    phase1.search.facc = 0.8
 
     return al.PipelineDataset(name, phase1)
 
