@@ -1,15 +1,15 @@
 import autolens as al
 import autolens.plot as aplt
 
-from test_autolens.simulate.imaging import simulate_util
+from test_autolens.simulators.imaging import instrument_util
 
 # In this tutorial, we'll introduce a new pixelization, called an adaptive-pixelization. This pixelization doesn't use
 # uniform grid of rectangular pixels, but instead uses ir'Voronoi' pixels. So, why would we want to do that?
 # Lets take another look at the rectangular grid, and think about its weakness.
 
 # Lets quickly remind ourselves of the image, and the 3.0" circular mask we'll use to mask it.
-imaging = simulate_util.load_test_imaging(
-    data_type="lens_mass__source_cuspy", data_resolution="hst"
+imaging = instrument_util.load_test_imaging(
+    data_name="lens_sie__source_cuspy", instrument="hst"
 )
 mask = al.Mask.circular(
     shape_2d=imaging.shape_2d,
